import { deviceFetch } from '../../../api/fetch';

// pages/components/EquipmentState/EquipmentState.js
Component({
  lifetimes: {
    attached() {},
  },
  /**
   * 组件的属性列表
   */
  properties: {
    areaId: {
      type: Number,
      value: 0,
      observer(newVal) {
        this.fetchAll();
      },
    },
  },

  /**
   * 组件的初始数据
   */
  data: {
    status: 'enable',
    tabs: [],
    pagination: {
      enable: {
        pageNum: 1,
        pageSize: 15,
      },
      forbidden: {
        pageNum: 1,
        pageSize: 15,
      },
      online: {
        pageNum: 1,
        pageSize: 15,
      },
      offline: {
        pageNum: 1,
        pageSize: 15,
      },
    },
    dataList: {
      enable: [],
      forbidden: [],
      online: [],
      offline: [],
    },
  },

  /**
   * 组件的方法列表
   */
  methods: {
    fetchAll() {
      this.fetchData();
      this.refreshList();
    },
    fetchData() {
      deviceFetch({
        url: `/device/report/deviceStautsCount/${this.data.areaId}`,
      })
        .then(res => {
          console.log(res);
          const list = res.data.map(item => {
            let label = '';
            switch (item.status) {
              case 'enable':
                label = '启用设备';
                break;
              case 'forbidden':
                label = '禁用设备';
                break;
              case 'online':
                label = '在线设备';
                break;
              case 'offline':
                label = '离线设备';
                break;
              default:
                break;
            }
            return {
              ...item,
              label,
            };
          });
          this.setData({
            tabs: list,
          });
        })
        .catch(err => {
          console.log(err);
        });
    },
    fetchList(entity) {
      return deviceFetch({
        url: `/device/report/status/${this.data.status}`,
        data: {
          areaId: this.data.areaId,
          pageNum: this.data.pagination[this.data.status].pageNum,
          pageSize: this.data.pagination[this.data.status].pageSize,
          ...entity,
        },
      });
    },
    refreshList() {
      wx.showLoading({
        title: '加载中',
        mask: true,
      });
      this.fetchList()
        .then(res => {
          wx.hideLoading();
          console.log(res);
          if (res.data && res.data.length) {
            this.setData({
              ['dataList.' + this.data.status]: res.data,
            });
          } else {
            this.setData({
              ['dataList.' + this.data.status]: [],
            });
          }
        })
        .catch(err => {
          wx.hideLoading();
          console.log(err);
        });
    },
    getMoreListItem() {
      wx.showLoading({
        title: '加载中',
        mask: true,
      });
      let nextPage = this.data.pagination[this.data.status].pageNum + 1;
      this.fetchList({
        pageNum: nextPage,
      })
        .then(res => {
          wx.hideLoading();
          console.log(res);
          if (res.data && res.data.length) {
            this.setData({
              ['dataList.' + this.data.status]: [
                ...this.data.dataList[this.data.status],
                ...res.data,
              ],
              ['pagination.' + this.data.status + '.pageNum']: nextPage,
            });
          }
        })
        .catch(err => {
          wx.hideLoading();
          console.log(err);
        });
    },
    changeTab(e) {
      const { status } = e.currentTarget.dataset;
      console.log(e, status);
      this.setData({
        status,
      });
      if (!this.data.dataList[status].length) this.refreshList();
    },
    openEquipment(e) {
      const { code, type } = e.currentTarget.dataset;
      console.log(code);
      deviceFetch({
        url: `/device/${code}/${type}/enable`,
        method: 'POST',
      })
        .then(res => {
          wx.showToast({
            title: res.msg || '操作成功',
          });
          this.refreshList();
        })
        .catch(err => {
          console.log(err);
        });
    },
    closeEquipment(e) {
      const { code, type } = e.currentTarget.dataset;
      console.log(code);
      deviceFetch({
        url: `/device/${code}/${type}/forbidden`,
        method: 'POST',
      })
        .then(res => {
          wx.showToast({
            title: res.msg || '操作成功',
          });
          this.refreshList();
        })
        .catch(err => {
          console.log(err);
        });
    },
  },
});
